! ESA (C) 2000-2018 
!
! This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
!
!    SAS is free software: you can redistribute it and/or modify
!    it under the terms of the GNU General Public License as published by
!    the Free Software Foundation, either version 3 of the License, or
!    (at your option) any later version.
!
!    SAS is distributed in the hope that it will be useful,
!    but WITHOUT ANY WARRANTY; without even the implied warranty of
!    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!    GNU General Public License for more details.
!
!    You should have received a copy of the GNU General Public License
!    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
!--------------------------------------------------------------------
program checkoutput
!--------------------------------------------------------------------
! test if output source counts and rates deviate by more than 5 %
! from reference data set
! test if output source position deviate by more than 1 pixel from 
! reference data set

use dal
use errorhandling

implicit none

integer(kind=int32) :: i, itest, nrow1, nrow2
type(DataSetT)  :: set1, set2
type(TableT)    :: tab1, tab2
Type(ColumnT)   :: scol1, scol2, rcol1, rcol2, xcol1, xcol2, ycol1, ycol2
real(kind=single), dimension(:), pointer :: scts1, scts2
integer :: ok
character(len=17), dimension(3) :: &
   list = (/"test.fits        ","lockman_srcs.fits","blah.fits        "/), &
   ref  = (/"test.ref         ","lockman_srcs.ref ","blah.ref         "/)
      
do itest = 1, 2

  write(*,*) "read",list(itest)

  set1 = dataSet(list(itest), read)
  tab1 = table(set1,"SRCLIST")
  nrow1 = numberOfRows(tab1)
  scol1 = column(tab1,"M1_TOT", read)
  scts1 => real32Data(scol1)

  set2 = dataSet(ref(itest), read)
  tab2 = table(set2,"SRCLIST")
  nrow2 = numberOfRows(tab2)
  scol2 = column(tab2,"M1_TOT", read)
  scts2 => real32Data(scol2)

  write(*,*) "read done",list(itest)
  

  ok = abs(nrow1-nrow2)

  write(*,*) "begin check ",list(itest)

  do i = 0, min(5,nrow1-1)
      if (scts1(i) < 0.90*scts2(i) .or. &
          scts1(i) > 1.10*scts2(i)) then
        ok = ok + 1
      end if
  end do

  write(*,*) "done check ",list(itest)


  call release(scol1)
  call release(scol2)
  call release(tab1)
  call release(tab2)
  call release(set1)
  call release(set2)

end do

if (ok > 2) then
  print *, "test failed"
  call error("test failed","source list contains wrong values")
end if
  
end program checkoutput


